@@ -11,9 +11,12 @@ use Class::Tiny {
 sub BUILD {
     my $self = shift;
 
-    # check non-lazy
+    # Check non-lazy
     $self->state;
     $self->timestamp;
+
+    # Return nothing (will be ignored anyway)
+    return;
 }
 
 1;
